aboutsummaryrefslogtreecommitdiff
path: root/backend.h
diff options
context:
space:
mode:
authorPetr Machata <pmachata@redhat.com>2012-05-29 00:42:59 +0200
committerPetr Machata <pmachata@redhat.com>2012-08-29 19:03:17 +0200
commitbac2da505ee174b7fb984b975c5938f88f0dbab2 (patch)
tree8435ec7dae6d5cc5284822a2e2378f33f192d5d4 /backend.h
parent26ef4cadd7d5ed7a525bd88cf9d0f05fc07f69de (diff)
downloadltrace-bac2da505ee174b7fb984b975c5938f88f0dbab2.tar.gz
Move target_address_t to arch.h, rename to arch_addr_t
Note that the placement under arch.h is currently conceptual only. Since no backend defines ARCH_HAVE_ADDRESS_TYPES, it's actually in sysdep.h in all cases.
Diffstat (limited to 'backend.h')
-rw-r--r--backend.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/backend.h b/backend.h
index 08306e1..29688ea 100644
--- a/backend.h
+++ b/backend.h
@@ -22,6 +22,8 @@
#define BACKEND_H
#include "forward.h"
+#include "sysdep.h"
+
#include <gelf.h>
enum process_status {
@@ -33,8 +35,6 @@ enum process_status {
ps_other, /* Necessary other states can be added as needed. */
};
-typedef void *target_address_t;
-
/*
* This file contains documentation of back end interface. Some of
* these may be implemented on an OS level (i.e. they are the same
@@ -93,7 +93,7 @@ void get_arch_dep(struct Process *proc);
* XXX note that the IP must fit into an arch pointer. This prevents
* us to use 32-bit ltrace to trace 64-bit process, even on arches
* that would otherwise support this. Above we have a definition of
* target_address_t. This should be converted to an integral type and
* used for target addresses throughout. */
void *get_instruction_pointer(struct Process *proc);
@@ -183,7 +183,7 @@ void *sym2addr(struct Process *proc, struct library_symbol *sym);
/* Called at some point after we have attached to PROC. This callback
* should insert an introspection breakpoint for handling dynamic
* linker library loads. */
-int linkmap_init(struct Process *proc, target_address_t dyn_addr);
+int linkmap_init(struct Process *proc, arch_addr_t dyn_addr);
/* Called for breakpoints defined over an artificial symbol "". This
* can be used (like it is on Linux/GNU) to add more breakpoints
@@ -240,8 +240,8 @@ int arch_process_exec(struct Process *proc);
* otherwise. Sets *ENTRYP and *INTERP_BIASP to non-zero values if
* the corresponding value is known. Unknown values are set to 0. */
int process_get_entry(struct Process *proc,
- target_address_t *entryp,
- target_address_t *interp_biasp);
+ arch_addr_t *entryp,
+ arch_addr_t *interp_biasp);
/* This is called after the dynamic linker is done with the
* process startup. */
@@ -93,7 +93,7 @@ void get_arch_dep(struct Process *proc);
* us to use 32-bit ltrace to trace 64-bit process, even on arches
* that would otherwise support this. Above we have a definition of
- * target_address_t. This should be converted to an integral type and
+ * arch_addr_t. This should be converted to an integral type and
* used for target addresses throughout. */
void *get_instruction_pointer(struct Process *proc);